"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ExtendedKeyUsageTypedDict(TypedDict):
    any: NotRequired[bool]
    apple_code_signing: NotRequired[bool]
    apple_code_signing_development: NotRequired[bool]
    apple_code_signing_third_party: NotRequired[bool]
    apple_crypto_development_env: NotRequired[bool]
    apple_crypto_env: NotRequired[bool]
    apple_crypto_maintenance_env: NotRequired[bool]
    apple_crypto_production_env: NotRequired[bool]
    apple_crypto_qos: NotRequired[bool]
    apple_crypto_test_env: NotRequired[bool]
    apple_crypto_tier0_qos: NotRequired[bool]
    apple_crypto_tier1_qos: NotRequired[bool]
    apple_crypto_tier2_qos: NotRequired[bool]
    apple_crypto_tier3_qos: NotRequired[bool]
    apple_ichat_encryption: NotRequired[bool]
    apple_ichat_signing: NotRequired[bool]
    apple_resource_signing: NotRequired[bool]
    apple_software_update_signing: NotRequired[bool]
    apple_system_identity: NotRequired[bool]
    client_auth: NotRequired[bool]
    code_signing: NotRequired[bool]
    dvcs: NotRequired[bool]
    eap_over_lan: NotRequired[bool]
    eap_over_ppp: NotRequired[bool]
    email_protection: NotRequired[bool]
    ipsec_end_system: NotRequired[bool]
    ipsec_intermediate_system_usage: NotRequired[bool]
    ipsec_tunnel: NotRequired[bool]
    ipsec_user: NotRequired[bool]
    microsoft_ca_exchange: NotRequired[bool]
    microsoft_cert_trust_list_signing: NotRequired[bool]
    microsoft_csp_signature: NotRequired[bool]
    microsoft_document_signing: NotRequired[bool]
    microsoft_drm: NotRequired[bool]
    microsoft_drm_individualization: NotRequired[bool]
    microsoft_efs_recovery: NotRequired[bool]
    microsoft_embedded_nt_crypto: NotRequired[bool]
    microsoft_encrypted_file_system: NotRequired[bool]
    microsoft_enrollment_agent: NotRequired[bool]
    microsoft_kernel_mode_code_signing: NotRequired[bool]
    microsoft_key_recovery_21: NotRequired[bool]
    microsoft_key_recovery_3: NotRequired[bool]
    microsoft_license_server: NotRequired[bool]
    microsoft_licenses: NotRequired[bool]
    microsoft_lifetime_signing: NotRequired[bool]
    microsoft_mobile_device_software: NotRequired[bool]
    microsoft_nt5_crypto: NotRequired[bool]
    microsoft_oem_whql_crypto: NotRequired[bool]
    microsoft_qualified_subordinate: NotRequired[bool]
    microsoft_root_list_signer: NotRequired[bool]
    microsoft_server_gated_crypto: NotRequired[bool]
    microsoft_sgc_serialized: NotRequired[bool]
    microsoft_smart_display: NotRequired[bool]
    microsoft_smartcard_logon: NotRequired[bool]
    microsoft_system_health: NotRequired[bool]
    microsoft_system_health_loophole: NotRequired[bool]
    microsoft_timestamp_signing: NotRequired[bool]
    microsoft_whql_crypto: NotRequired[bool]
    netscape_server_gated_crypto: NotRequired[bool]
    ocsp_signing: NotRequired[bool]
    sbgp_cert_aa_service_auth: NotRequired[bool]
    server_auth: NotRequired[bool]
    time_stamping: NotRequired[bool]
    unknown: NotRequired[Nullable[List[str]]]


class ExtendedKeyUsage(BaseModel):
    any: Optional[bool] = None

    apple_code_signing: Optional[bool] = None

    apple_code_signing_development: Optional[bool] = None

    apple_code_signing_third_party: Optional[bool] = None

    apple_crypto_development_env: Optional[bool] = None

    apple_crypto_env: Optional[bool] = None

    apple_crypto_maintenance_env: Optional[bool] = None

    apple_crypto_production_env: Optional[bool] = None

    apple_crypto_qos: Optional[bool] = None

    apple_crypto_test_env: Optional[bool] = None

    apple_crypto_tier0_qos: Optional[bool] = None

    apple_crypto_tier1_qos: Optional[bool] = None

    apple_crypto_tier2_qos: Optional[bool] = None

    apple_crypto_tier3_qos: Optional[bool] = None

    apple_ichat_encryption: Optional[bool] = None

    apple_ichat_signing: Optional[bool] = None

    apple_resource_signing: Optional[bool] = None

    apple_software_update_signing: Optional[bool] = None

    apple_system_identity: Optional[bool] = None

    client_auth: Optional[bool] = None

    code_signing: Optional[bool] = None

    dvcs: Optional[bool] = None

    eap_over_lan: Optional[bool] = None

    eap_over_ppp: Optional[bool] = None

    email_protection: Optional[bool] = None

    ipsec_end_system: Optional[bool] = None

    ipsec_intermediate_system_usage: Optional[bool] = None

    ipsec_tunnel: Optional[bool] = None

    ipsec_user: Optional[bool] = None

    microsoft_ca_exchange: Optional[bool] = None

    microsoft_cert_trust_list_signing: Optional[bool] = None

    microsoft_csp_signature: Optional[bool] = None

    microsoft_document_signing: Optional[bool] = None

    microsoft_drm: Optional[bool] = None

    microsoft_drm_individualization: Optional[bool] = None

    microsoft_efs_recovery: Optional[bool] = None

    microsoft_embedded_nt_crypto: Optional[bool] = None

    microsoft_encrypted_file_system: Optional[bool] = None

    microsoft_enrollment_agent: Optional[bool] = None

    microsoft_kernel_mode_code_signing: Optional[bool] = None

    microsoft_key_recovery_21: Optional[bool] = None

    microsoft_key_recovery_3: Optional[bool] = None

    microsoft_license_server: Optional[bool] = None

    microsoft_licenses: Optional[bool] = None

    microsoft_lifetime_signing: Optional[bool] = None

    microsoft_mobile_device_software: Optional[bool] = None

    microsoft_nt5_crypto: Optional[bool] = None

    microsoft_oem_whql_crypto: Optional[bool] = None

    microsoft_qualified_subordinate: Optional[bool] = None

    microsoft_root_list_signer: Optional[bool] = None

    microsoft_server_gated_crypto: Optional[bool] = None

    microsoft_sgc_serialized: Optional[bool] = None

    microsoft_smart_display: Optional[bool] = None

    microsoft_smartcard_logon: Optional[bool] = None

    microsoft_system_health: Optional[bool] = None

    microsoft_system_health_loophole: Optional[bool] = None

    microsoft_timestamp_signing: Optional[bool] = None

    microsoft_whql_crypto: Optional[bool] = None

    netscape_server_gated_crypto: Optional[bool] = None

    ocsp_signing: Optional[bool] = None

    sbgp_cert_aa_service_auth: Optional[bool] = None

    server_auth: Optional[bool] = None

    time_stamping: Optional[bool] = None

    unknown: OptionalNullable[List[str]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "any",
            "apple_code_signing",
            "apple_code_signing_development",
            "apple_code_signing_third_party",
            "apple_crypto_development_env",
            "apple_crypto_env",
            "apple_crypto_maintenance_env",
            "apple_crypto_production_env",
            "apple_crypto_qos",
            "apple_crypto_test_env",
            "apple_crypto_tier0_qos",
            "apple_crypto_tier1_qos",
            "apple_crypto_tier2_qos",
            "apple_crypto_tier3_qos",
            "apple_ichat_encryption",
            "apple_ichat_signing",
            "apple_resource_signing",
            "apple_software_update_signing",
            "apple_system_identity",
            "client_auth",
            "code_signing",
            "dvcs",
            "eap_over_lan",
            "eap_over_ppp",
            "email_protection",
            "ipsec_end_system",
            "ipsec_intermediate_system_usage",
            "ipsec_tunnel",
            "ipsec_user",
            "microsoft_ca_exchange",
            "microsoft_cert_trust_list_signing",
            "microsoft_csp_signature",
            "microsoft_document_signing",
            "microsoft_drm",
            "microsoft_drm_individualization",
            "microsoft_efs_recovery",
            "microsoft_embedded_nt_crypto",
            "microsoft_encrypted_file_system",
            "microsoft_enrollment_agent",
            "microsoft_kernel_mode_code_signing",
            "microsoft_key_recovery_21",
            "microsoft_key_recovery_3",
            "microsoft_license_server",
            "microsoft_licenses",
            "microsoft_lifetime_signing",
            "microsoft_mobile_device_software",
            "microsoft_nt5_crypto",
            "microsoft_oem_whql_crypto",
            "microsoft_qualified_subordinate",
            "microsoft_root_list_signer",
            "microsoft_server_gated_crypto",
            "microsoft_sgc_serialized",
            "microsoft_smart_display",
            "microsoft_smartcard_logon",
            "microsoft_system_health",
            "microsoft_system_health_loophole",
            "microsoft_timestamp_signing",
            "microsoft_whql_crypto",
            "netscape_server_gated_crypto",
            "ocsp_signing",
            "sbgp_cert_aa_service_auth",
            "server_auth",
            "time_stamping",
            "unknown",
        ]
        nullable_fields = ["unknown"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SSHEndpointIDTypedDict(TypedDict):
    comment: NotRequired[str]
    protocol_version: NotRequired[str]
    raw: NotRequired[str]
    software_version: NotRequired[str]


class SSHEndpointID(BaseModel):
    comment: Optional[str] = None

    protocol_version: Optional[str] = None

    raw: Optional[str] = None

    software_version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .amqp_protocol import AmqpProtocol, AmqpProtocolTypedDict
from .amqp_version import AmqpVersion, AmqpVersionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AmqpTypedDict(TypedDict):
    explicit_tls: NotRequired[bool]
    r"""Connected via a TLS connection after initial handshake"""
    implicit_tls: NotRequired[bool]
    r"""Connected via a TLS wrapped connection (AMQPS)"""
    protocol_id: NotRequired[AmqpProtocolTypedDict]
    version: NotRequired[AmqpVersionTypedDict]


class Amqp(BaseModel):
    explicit_tls: Optional[bool] = None
    r"""Connected via a TLS connection after initial handshake"""

    implicit_tls: Optional[bool] = None
    r"""Connected via a TLS wrapped connection (AMQPS)"""

    protocol_id: Optional[AmqpProtocol] = None

    version: Optional[AmqpVersion] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchSystemInfoVerTypedDict(TypedDict):
    build_date: NotRequired[str]
    build_flavor: NotRequired[str]
    build_hash: NotRequired[str]
    build_snapshot: NotRequired[bool]
    build_type: NotRequired[str]
    lucene_version: NotRequired[str]
    min_idx_compat_ver: NotRequired[str]
    min_wire_compat_ver: NotRequired[str]
    number: NotRequired[str]


class ElasticSearchSystemInfoVer(BaseModel):
    build_date: Optional[str] = None

    build_flavor: Optional[str] = None

    build_hash: Optional[str] = None

    build_snapshot: Optional[bool] = None

    build_type: Optional[str] = None

    lucene_version: Optional[str] = None

    min_idx_compat_ver: Optional[str] = None

    min_wire_compat_ver: Optional[str] = None

    number: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SpiceTypedDict(TypedDict):
    major_version: NotRequired[int]
    minor_version: NotRequired[int]
    tls_only: NotRequired[bool]
    x509_public_key: NotRequired[str]


class Spice(BaseModel):
    major_version: Optional[int] = None

    minor_version: Optional[int] = None

    tls_only: Optional[bool] = None

    x509_public_key: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .zeromq_greeting import ZeromqGreeting, ZeromqGreetingTypedDict
from .zeromq_handshake import ZeromqHandshake, ZeromqHandshakeTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ZeromqTypedDict(TypedDict):
    greeting: NotRequired[ZeromqGreetingTypedDict]
    handshake: NotRequired[ZeromqHandshakeTypedDict]
    subscription_data: NotRequired[str]
    subscription_match: NotRequired[Dict[str, bool]]


class Zeromq(BaseModel):
    greeting: Optional[ZeromqGreeting] = None

    handshake: Optional[ZeromqHandshake] = None

    subscription_data: Optional[str] = None

    subscription_match: Optional[Dict[str, bool]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .distinguishedname import DistinguishedName, DistinguishedNameTypedDict
from .edipartyname import EdiPartyName, EdiPartyNameTypedDict
from .othername import OtherName, OtherNameTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class GeneralNamesTypedDict(TypedDict):
    directory_names: NotRequired[Nullable[List[DistinguishedNameTypedDict]]]
    r"""The parsed directoryName entries in the GeneralName."""
    dns_names: NotRequired[Nullable[List[str]]]
    r"""The parsed dNSName entries in the GeneralName."""
    edi_party_names: NotRequired[Nullable[List[EdiPartyNameTypedDict]]]
    r"""The parsed eDIPartyName entries in the GeneralName."""
    email_addresses: NotRequired[Nullable[List[str]]]
    r"""The parsed rfc822Name entries in the GeneralName."""
    ip_addresses: NotRequired[Nullable[List[str]]]
    r"""The parsed ipAddress entries in the GeneralName."""
    other_names: NotRequired[Nullable[List[OtherNameTypedDict]]]
    r"""The parsed otherName entries in the GeneralName. An arbitrary binary value identified by an OID."""
    registered_ids: NotRequired[Nullable[List[str]]]
    r"""The parsed registeredID entries in the GeneralName. Stored in dotted-decimal format."""
    uniform_resource_identifiers: NotRequired[Nullable[List[str]]]
    r"""The parsed uniformResourceIdentifier entries in the GeneralName."""


class GeneralNames(BaseModel):
    directory_names: OptionalNullable[List[DistinguishedName]] = UNSET
    r"""The parsed directoryName entries in the GeneralName."""

    dns_names: OptionalNullable[List[str]] = UNSET
    r"""The parsed dNSName entries in the GeneralName."""

    edi_party_names: OptionalNullable[List[EdiPartyName]] = UNSET
    r"""The parsed eDIPartyName entries in the GeneralName."""

    email_addresses: OptionalNullable[List[str]] = UNSET
    r"""The parsed rfc822Name entries in the GeneralName."""

    ip_addresses: OptionalNullable[List[str]] = UNSET
    r"""The parsed ipAddress entries in the GeneralName."""

    other_names: OptionalNullable[List[OtherName]] = UNSET
    r"""The parsed otherName entries in the GeneralName. An arbitrary binary value identified by an OID."""

    registered_ids: OptionalNullable[List[str]] = UNSET
    r"""The parsed registeredID entries in the GeneralName. Stored in dotted-decimal format."""

    uniform_resource_identifiers: OptionalNullable[List[str]] = UNSET
    r"""The parsed uniformResourceIdentifier entries in the GeneralName."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "directory_names",
            "dns_names",
            "edi_party_names",
            "email_addresses",
            "ip_addresses",
            "other_names",
            "registered_ids",
            "uniform_resource_identifiers",
        ]
        nullable_fields = [
            "directory_names",
            "dns_names",
            "edi_party_names",
            "email_addresses",
            "ip_addresses",
            "other_names",
            "registered_ids",
            "uniform_resource_identifiers",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_clustercombinedinfo_indices_docs import (
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocs,
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocsTypedDict,
)
from .elasticsearch_resultsnodeinfo_clustercombinedinfo_indices_store import (
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStore,
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStoreTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesTypedDict(TypedDict):
    count: NotRequired[int]
    docs: NotRequired[
        ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocsTypedDict
    ]
    store: NotRequired[
        ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStoreTypedDict
    ]


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndices(BaseModel):
    count: Optional[int] = None

    docs: Optional[ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocs] = None

    store: Optional[ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStore] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .saprouter_clientinfo import SapRouterClientInfo, SapRouterClientInfoTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class SapRouterRouterInfoTypedDict(TypedDict):
    connected_client_info: NotRequired[Nullable[List[SapRouterClientInfoTypedDict]]]
    num_clients: NotRequired[int]
    parent_pid: NotRequired[int]
    parent_port: NotRequired[int]
    pid: NotRequired[int]
    port: NotRequired[int]
    routtab_relative_directory: NotRequired[str]
    sap_router_absolute_directory: NotRequired[str]
    started_on: NotRequired[str]


class SapRouterRouterInfo(BaseModel):
    connected_client_info: OptionalNullable[List[SapRouterClientInfo]] = UNSET

    num_clients: Optional[int] = None

    parent_pid: Optional[int] = None

    parent_port: Optional[int] = None

    pid: Optional[int] = None

    port: Optional[int] = None

    routtab_relative_directory: Optional[str] = None

    sap_router_absolute_directory: Optional[str] = None

    started_on: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "connected_client_info",
            "num_clients",
            "parent_pid",
            "parent_port",
            "pid",
            "port",
            "routtab_relative_directory",
            "sap_router_absolute_directory",
            "started_on",
        ]
        nullable_fields = ["connected_client_info"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MediaProfileTypedDict(TypedDict):
    max_profile_count: NotRequired[int]


class MediaProfile(BaseModel):
    max_profile_count: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MmsTypedDict(TypedDict):
    model: NotRequired[str]
    revision: NotRequired[str]
    vendor: NotRequired[str]


class Mms(BaseModel):
    model: Optional[str] = None

    revision: Optional[str] = None

    vendor: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GeneralSubtreeIPTypedDict(TypedDict):
    begin: NotRequired[str]
    r"""The first IP address in the range."""
    cidr: NotRequired[str]
    r"""The CIDR specifying the subtree."""
    end: NotRequired[str]
    r"""The last IP address in the range."""
    mask: NotRequired[str]
    r"""The subnet mask of the CIDR."""


class GeneralSubtreeIP(BaseModel):
    begin: Optional[str] = None
    r"""The first IP address in the range."""

    cidr: Optional[str] = None
    r"""The CIDR specifying the subtree."""

    end: Optional[str] = None
    r"""The last IP address in the range."""

    mask: Optional[str] = None
    r"""The subnet mask of the CIDR."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .endpointscanned import EndpointScanned, EndpointScannedTypedDict
from .forwarddnsresolved import ForwardDNSResolved, ForwardDNSResolvedTypedDict
from .jarmscanned import JarmScanned, JarmScannedTypedDict
from .locationupdated import LocationUpdated, LocationUpdatedTypedDict
from .reversednsresolved import ReverseDNSResolved, ReverseDNSResolvedTypedDict
from .routeupdated import RouteUpdated, RouteUpdatedTypedDict
from .servicescanned import ServiceScanned, ServiceScannedTypedDict
from .whoisupdated import WhoisUpdated, WhoisUpdatedTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class HostTimelineEventTypedDict(TypedDict):
    endpoint_scanned: NotRequired[EndpointScannedTypedDict]
    event_time: NotRequired[str]
    forward_dns_resolved: NotRequired[ForwardDNSResolvedTypedDict]
    jarm_scanned: NotRequired[JarmScannedTypedDict]
    location_updated: NotRequired[LocationUpdatedTypedDict]
    reverse_dns_resolved: NotRequired[ReverseDNSResolvedTypedDict]
    route_updated: NotRequired[RouteUpdatedTypedDict]
    service_scanned: NotRequired[ServiceScannedTypedDict]
    whois_updated: NotRequired[WhoisUpdatedTypedDict]


class HostTimelineEvent(BaseModel):
    endpoint_scanned: Optional[EndpointScanned] = None

    event_time: Optional[str] = None

    forward_dns_resolved: Optional[ForwardDNSResolved] = None

    jarm_scanned: Optional[JarmScanned] = None

    location_updated: Optional[LocationUpdated] = None

    reverse_dns_resolved: Optional[ReverseDNSResolved] = None

    route_updated: Optional[RouteUpdated] = None

    service_scanned: Optional[ServiceScanned] = None

    whois_updated: Optional[WhoisUpdated] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .http_favicon import HTTPFavicon, HTTPFaviconTypedDict
from .http_repeatedheaders import HTTPRepeatedHeaders, HTTPRepeatedHeadersTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import NotRequired, TypedDict


class HTTPTypedDict(TypedDict):
    body: NotRequired[str]
    r"""The body of the HTTP response. For hosts without a name, the first 64KB are available. For hosts with a name, only 6KB are available."""
    body_hash_sha1: NotRequired[str]
    body_hash_sha256: NotRequired[str]
    body_hash_tlsh: NotRequired[str]
    body_size: NotRequired[int]
    r"""The length, in bytes, of services.http.response.body; at most, 64KB."""
    favicons: NotRequired[Nullable[List[HTTPFaviconTypedDict]]]
    headers: NotRequired[Dict[str, HTTPRepeatedHeadersTypedDict]]
    r"""The key-value header pairs included in the response."""
    html_tags: NotRequired[Nullable[List[str]]]
    r"""A list of the <title> and <meta> tags from services.http.response.body."""
    html_title: NotRequired[str]
    r"""The title of the HTML page: the inner contents of the <title> tag in the response body, if present."""
    protocol: NotRequired[str]
    r"""The protocol field of the response, which includes the claimed HTTP version number."""
    status_code: NotRequired[int]
    r"""A 3-digit integer result code indicating the result of the services.http.request."""
    status_reason: NotRequired[str]
    r"""A human-readable phrase describing the status code."""
    supported_versions: NotRequired[Nullable[List[str]]]
    uri: NotRequired[str]
    r"""The full path used to make the request, which includes the scheme, host, port (when non-standard), and endpoint."""


class HTTP(BaseModel):
    body: Optional[str] = None
    r"""The body of the HTTP response. For hosts without a name, the first 64KB are available. For hosts with a name, only 6KB are available."""

    body_hash_sha1: Optional[str] = None

    body_hash_sha256: Optional[str] = None

    body_hash_tlsh: Optional[str] = None

    body_size: Optional[int] = None
    r"""The length, in bytes, of services.http.response.body; at most, 64KB."""

    favicons: OptionalNullable[List[HTTPFavicon]] = UNSET

    headers: Optional[Dict[str, HTTPRepeatedHeaders]] = None
    r"""The key-value header pairs included in the response."""

    html_tags: OptionalNullable[List[str]] = UNSET
    r"""A list of the <title> and <meta> tags from services.http.response.body."""

    html_title: Optional[str] = None
    r"""The title of the HTML page: the inner contents of the <title> tag in the response body, if present."""

    protocol: Optional[str] = None
    r"""The protocol field of the response, which includes the claimed HTTP version number."""

    status_code: Optional[int] = None
    r"""A 3-digit integer result code indicating the result of the services.http.request."""

    status_reason: Optional[str] = None
    r"""A human-readable phrase describing the status code."""

    supported_versions: OptionalNullable[List[str]] = UNSET

    uri: Optional[str] = None
    r"""The full path used to make the request, which includes the scheme, host, port (when non-standard), and endpoint."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "body",
            "body_hash_sha1",
            "body_hash_sha256",
            "body_hash_tlsh",
            "body_size",
            "favicons",
            "headers",
            "html_tags",
            "html_title",
            "protocol",
            "status_code",
            "status_reason",
            "supported_versions",
            "uri",
        ]
        nullable_fields = ["favicons", "html_tags", "supported_versions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .prometheus_response import PrometheusResponse, PrometheusResponseTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PrometheusTypedDict(TypedDict):
    response: NotRequired[PrometheusResponseTypedDict]


class Prometheus(BaseModel):
    response: Optional[PrometheusResponse] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cpe import Cpe, CpeTypedDict
from .cpe_lifecycle import CPELifeCycle, CPELifeCycleTypedDict
from .evidence import Evidence, EvidenceTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class Source(str, Enum):
    UNKNOWN = ""
    CENSYS = "censys"
    RECOG = "recog"
    WAPPALYZER = "wappalyzer"
    THIRD_PARTY = "third_party"


class AttributeTypedDict(TypedDict):
    components: NotRequired[Nullable[List[CpeTypedDict]]]
    confidence: NotRequired[float]
    cpe: NotRequired[str]
    edition: NotRequired[str]
    evidence: NotRequired[Nullable[List[EvidenceTypedDict]]]
    life_cycle: NotRequired[CPELifeCycleTypedDict]
    part: NotRequired[str]
    product: NotRequired[str]
    source: NotRequired[Source]
    type: NotRequired[Nullable[List[str]]]
    update: NotRequired[str]
    vendor: NotRequired[str]
    version: NotRequired[str]


class Attribute(BaseModel):
    components: OptionalNullable[List[Cpe]] = UNSET

    confidence: Optional[float] = None

    cpe: Optional[str] = None

    edition: Optional[str] = None

    evidence: OptionalNullable[List[Evidence]] = UNSET

    life_cycle: Optional[CPELifeCycle] = None

    part: Optional[str] = None

    product: Optional[str] = None

    source: Optional[Source] = None

    type: OptionalNullable[List[str]] = UNSET

    update: Optional[str] = None

    vendor: Optional[str] = None

    version: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "components",
            "confidence",
            "cpe",
            "edition",
            "evidence",
            "life_cycle",
            "part",
            "product",
            "source",
            "type",
            "update",
            "vendor",
            "version",
        ]
        nullable_fields = ["components", "evidence", "type"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
